import pandas as pd

df = pd.read_csv('./Data/temporary.txt', sep="\t", index_col=0)
drag = df[['wSpeed.10']]
drag.index = pd.to_datetime(drag.index)

# Get the maximum hourly wind speed per day
drag = drag.resample('d').max()
drag.columns = ['wSpeed']

# Calculate drifting force with just solar panels
blocks = 284
blockw = 102.5 # width of one block in metres
blockl = 72.5 # length of one block in metres
Area = blocks*blockw*blockl  # depends on the installed blocks. max lake area=4 km2
aDensity = 1.367    # kg/m3 at -15ºC
Ca = 0.0085
Fawoi = []
drag.reset_index(level=0, inplace=True)
for i in range(0, len(drag), 1):
    Fawoi.insert(i, aDensity * Ca * Area * drag.at[i, 'wSpeed'] ** 2)
drag = drag.assign(Fawoi=Fawoi)
drag = drag.set_index('time')

# Calculate drifting force with ice
blocks = 284
blockw = 102.5 # width of one block in metres
blockl = 72.5 # length of one block in metres
Areawi = 4000000 - blocks*blockw*blockl  # depends on the installed blocks. max lake area=4 km2
Cai = 0.002
Fawi = []
Fawosp = []
drag.reset_index(level=0, inplace=True)
for i in range(0, len(drag), 1):
    if 6 <= drag.at[i,'time'].month <=11 :
        Fawi.insert(i, 0)
        Fawosp.insert(i, 0)
    else:
        Fawi.insert(i, (aDensity * Cai * Areawi * drag.at[i, 'wSpeed'] ** 2) + (aDensity * Ca * Area * drag.at[i, 'wSpeed'] ** 2))
        Fawosp.insert(i, aDensity * Cai * 4000000 * drag.at[i, 'wSpeed'] ** 2)
drag = drag.assign(Fawi=Fawi).assign(Fawosp=Fawosp)
drag = drag.set_index('time')

# Check and print the maximum forces with and without ice
Maxforcewi = drag['Fawi'].max()
Maxforcewoi = drag['Fawoi'].max()
Maxforcewosp = drag['Fawosp'].max()
Forceincrease = (Maxforcewi/Maxforcewosp-1)*100
print ('Max force with ice %s N' % Maxforcewi)
print ('Max force without ice %s N' % Maxforcewoi)
print ('Max force without solar panels %s N' % Maxforcewosp)
print ('Solar panels force increase %.2f%%' % Forceincrease)

# Properly name columns
drag.columns = ['wSpeed (m/s)','Drag force without ice (N)','Drag force with ice (N)','Drag force without solar panels (N)']

# Export Drag DataFrame
drag.to_csv(r'./Data/DataFrames/drag.csv', decimal=',')